@@ -1,10 +1,10 @@
 package antlr;
 
 /* ANTLR Translator Generator
- * Project led by Terence Parr at http://www.jGuru.com
+ * Project led by Terence Parr at http://www.cs.usfca.edu
  * Software rights: http://www.antlr.org/license.html
  *
- * $Id: //depot/code/org.antlr/release/antlr-2.7.4/antlr/CppCharFormatter.java#1 $
+ * $Id: //depot/code/org.antlr/release/antlr-2.7.7/antlr/CppCharFormatter.java#2 $
  */
 
 // C++ code generator by Pete Wells: pete@yamuna.demon.co.uk
@@ -21,6 +21,7 @@ class CppCharFormatter implements CharFormatter {
 	 *
 	 * @param c   The character of interest.
 	 * @param forCharLiteral  true to escape for char literal, false for string literal
+	 *        IGNORED!!
 	 */
 	public String escapeChar(int c, boolean forCharLiteral) {
 		// System.out.println("CppCharFormatter.escapeChar("+c+")");
@@ -29,8 +30,8 @@ class CppCharFormatter implements CharFormatter {
 		case '\t' : return "\\t";
 		case '\r' : return "\\r";
 		case '\\' : return "\\\\";
-		case '\'' : return forCharLiteral ? "\\'" : "'";
-		case '"' :  return forCharLiteral ? "\"" : "\\\"";
+		case '\'' : return "\\'";
+		case '"' :  return "\\\"";
 		default :
 			if ( c < ' ' || c > 126 )
 			{
