@@ -1,10 +1,10 @@
 package antlr;
 
 /* ANTLR Translator Generator
- * Project led by Terence Parr at http://www.jGuru.com
+ * Project led by Terence Parr at http://www.cs.usfca.edu
  * Software rights: http://www.antlr.org/license.html
  *
- * $Id: //depot/code/org.antlr/dev/klaren.dev/antlr/HTMLCodeGenerator.java#3 $
+ * $Id:$
  */
 
 /** TODO: strip comments from javadoc entries
@@ -155,9 +155,8 @@ public class DocBookCodeGenerator extends CodeGenerator {
     /** Generate the lexer HTML file */
     public void gen(LexerGrammar g) throws IOException {
         setGrammar(g);
-        antlrTool.reportProgress("Generating " + grammar.getClassName() + TokenTypesFileExt);
-        currentOutput = antlrTool.openOutputFile(grammar.getClassName() + TokenTypesFileExt);
-        //SAS: changed for proper text file io
+        antlrTool.reportProgress("Generating " + grammar.getClassName() + ".sgml");
+        currentOutput = antlrTool.openOutputFile(grammar.getClassName() + ".sgml");
 
         tabs = 0;
         doingLexRules = true;
