@@ -1,10 +1,10 @@
 package antlr;
 
 /* ANTLR Translator Generator
- * Project led by Terence Parr at http://www.jGuru.com
+ * Project led by Terence Parr at http://www.cs.usfca.edu
  * Software rights: http://www.antlr.org/license.html
  *
- * $Id: //depot/code/org.antlr/release/antlr-2.7.4/antlr/LexerGrammar.java#1 $
+ * $Id: //depot/code/org.antlr/release/antlr-2.7.7/antlr/LexerGrammar.java#2 $
  */
 
 import java.util.Hashtable;
@@ -35,7 +35,12 @@ class LexerGrammar extends Grammar {
 
     LexerGrammar(String className_, Tool tool_, String superClass) {
         super(className_, tool_, superClass);
-        charVocabulary = new BitSet();
+		// by default, use 0..127 for ASCII char vocabulary
+		BitSet cv = new BitSet();
+		for (int i = 0; i <= 127; i++) {
+			cv.add(i);
+		}
+		setCharVocabulary(cv);
 
         // Lexer usually has no default error handling
         defaultErrorHandler = false;
@@ -160,6 +165,10 @@ class LexerGrammar extends Grammar {
             antlrTool.warning("longestPossible option has been deprecated; ignoring it...", getFilename(), value.getLine(), value.getColumn());
             return true;
         }
+        if (key.equals("className")) {
+            super.setOption(key, value);
+            return true;
+        }
         if (super.setOption(key, value)) {
             return true;
         }
