@@ -1,10 +1,10 @@
 package antlr;
 
 /* ANTLR Translator Generator
- * Project led by Terence Parr at http://www.jGuru.com
+ * Project led by Terence Parr at http://www.cs.usfca.edu
  * Software rights: http://www.antlr.org/license.html
  *
- * $Id: //depot/code/org.antlr/release/antlr-2.7.4/antlr/Parser.java#1 $
+ * $Id: //depot/code/org.antlr/release/antlr-2.7.7/antlr/Parser.java#2 $
  */
 
 import antlr.collections.impl.BitSet;
@@ -40,8 +40,6 @@ import antlr.collections.impl.ASTArray;
  *
  * @see antlr.Token
  * @see antlr.TokenBuffer
- * @see antlr.Tokenizer
- * @see antlr.LL1Parser
  * @see antlr.LLkParser
  */
 
@@ -308,6 +306,12 @@ public abstract class Parser {
         }
     }
 
+	public void recover(RecognitionException ex,
+						BitSet tokenSet) throws TokenStreamException {
+		consume();
+		consumeUntil(tokenSet);
+	}
+
     public void rewind(int pos) {
         inputState.input.rewind(pos);
     }
