@@ -48,8 +48,8 @@ import antlr.SemanticException;
 	$getText		  -> new String(text.getBuffer(),_begin,text.length()-_begin)
 	$setToken(x)  -> _token = x
 	$setType(x)	  -> _ttype = x
-    $FOLLOW(r)    -> FOLLOW set name for rule r (optional arg)
-    $FIRST(r)     -> FIRST set name for rule r (optional arg)
+   $FOLLOW(r)    -> FOLLOW set name for rule r (optional arg)
+   $FIRST(r)     -> FIRST set name for rule r (optional arg)
  */
 public class ActionLexer extends antlr.CharScanner implements ActionLexerTokenTypes, TokenStream
  {
@@ -157,8 +157,8 @@ tryAgain:
 		int _saveIndex;
 		
 		{
-		int _cnt236=0;
-		_loop236:
+		int _cnt502=0;
+		_loop502:
 		do {
 			switch ( LA(1)) {
 			case '#':
@@ -176,10 +176,10 @@ tryAgain:
 					mSTUFF(false);
 				}
 			else {
-				if ( _cnt236>=1 ) { break _loop236; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
+				if ( _cnt502>=1 ) { break _loop502; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
 			}
 			}
-			_cnt236++;
+			_cnt502++;
 		} while (true);
 		}
 		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
@@ -218,11 +218,11 @@ tryAgain:
 			if ((LA(1)=='/') && (LA(2)=='*'||LA(2)=='/')) {
 				mCOMMENT(false);
 			}
-			else if ((LA(1)=='\r') && (LA(2)=='\n')) {
+			else if ((LA(1)=='\r') && (LA(2)=='\n') && (true)) {
 				match("\r\n");
 				newline();
 			}
-			else if ((LA(1)=='\\') && (LA(2)=='#')) {
+			else if ((LA(1)=='\\') && (LA(2)=='#') && (true)) {
 				match('\\');
 				match('#');
 				text.setLength(_begin); text.append("#");
@@ -233,11 +233,11 @@ tryAgain:
 				match(_tokenSet_1);
 				}
 			}
-			else if ((LA(1)=='\r') && (true)) {
+			else if ((LA(1)=='\r') && (true) && (true)) {
 				match('\r');
 				newline();
 			}
-			else if ((_tokenSet_2.member(LA(1))) && (true)) {
+			else if ((_tokenSet_2.member(LA(1))) && (true) && (true)) {
 				{
 				match(_tokenSet_2);
 				}
@@ -333,7 +333,7 @@ tryAgain:
 						}
 					
 			{
-			if ((_tokenSet_4.member(LA(1))) && (true)) {
+			if ((_tokenSet_4.member(LA(1))) && (true) && (true)) {
 				mWS(false);
 			}
 			else {
@@ -341,7 +341,7 @@ tryAgain:
 			
 			}
 			{
-			if ((LA(1)=='=') && (true)) {
+			if ((LA(1)=='=') && (true) && (true)) {
 				mVAR_ASSIGN(false);
 			}
 			else {
@@ -375,7 +375,7 @@ tryAgain:
 						}
 					
 			{
-			if ((_tokenSet_4.member(LA(1))) && (true)) {
+			if ((_tokenSet_4.member(LA(1))) && (true) && (true)) {
 				mWS(false);
 			}
 			else {
@@ -383,7 +383,7 @@ tryAgain:
 			
 			}
 			{
-			if ((LA(1)=='=') && (true)) {
+			if ((LA(1)=='=') && (true) && (true)) {
 				mVAR_ASSIGN(false);
 			}
 			else {
@@ -413,7 +413,99 @@ tryAgain:
 		Token a5=null;
 		Token a6=null;
 		
-		if ((LA(1)=='$') && (LA(2)=='a')) {
+		if ((LA(1)=='$') && (LA(2)=='F') && (LA(3)=='O')) {
+			match("$FOLLOW");
+			{
+			if ((_tokenSet_5.member(LA(1))) && (_tokenSet_6.member(LA(2))) && ((LA(3) >= '\u0003' && LA(3) <= '\u00ff'))) {
+				{
+				switch ( LA(1)) {
+				case '\t':  case '\n':  case '\r':  case ' ':
+				{
+					mWS(false);
+					break;
+				}
+				case '(':
+				{
+					break;
+				}
+				default:
+				{
+					throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());
+				}
+				}
+				}
+				match('(');
+				mTEXT_ARG(true);
+				a5=_returnToken;
+				match(')');
+			}
+			else {
+			}
+			
+			}
+			
+						String rule = currentRule.getRuleName();
+						if ( a5!=null ) {
+							rule = a5.getText();
+						}
+						String setName = generator.getFOLLOWBitSet(rule, 1);
+						// System.out.println("FOLLOW("+rule+")="+setName);
+						if ( setName==null ) {
+							reportError("$FOLLOW("+rule+")"+
+										": unknown rule or bad lookahead computation");
+						}
+						else {
+							text.setLength(_begin); text.append(setName);
+						}
+					
+		}
+		else if ((LA(1)=='$') && (LA(2)=='F') && (LA(3)=='I')) {
+			match("$FIRST");
+			{
+			if ((_tokenSet_5.member(LA(1))) && (_tokenSet_6.member(LA(2))) && ((LA(3) >= '\u0003' && LA(3) <= '\u00ff'))) {
+				{
+				switch ( LA(1)) {
+				case '\t':  case '\n':  case '\r':  case ' ':
+				{
+					mWS(false);
+					break;
+				}
+				case '(':
+				{
+					break;
+				}
+				default:
+				{
+					throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());
+				}
+				}
+				}
+				match('(');
+				mTEXT_ARG(true);
+				a6=_returnToken;
+				match(')');
+			}
+			else {
+			}
+			
+			}
+			
+						String rule = currentRule.getRuleName();
+						if ( a6!=null ) {
+							rule = a6.getText();
+						}
+						String setName = generator.getFIRSTBitSet(rule, 1);
+						// System.out.println("FIRST("+rule+")="+setName);
+						if ( setName==null ) {
+							reportError("$FIRST("+rule+")"+
+										": unknown rule or bad lookahead computation");
+						}
+						else {
+							text.setLength(_begin); text.append(setName);
+						}
+					
+		}
+		else if ((LA(1)=='$') && (LA(2)=='a')) {
 			match("$append");
 			{
 			switch ( LA(1)) {
@@ -540,98 +632,6 @@ tryAgain:
 			
 						text.setLength(_begin); text.append("text.substr(_begin,text.length()-_begin)");
 					
-		}
-		else if ((LA(1)=='$') && (LA(2)=='F')) {
-			match("$FOLLOW");
-			{
-			if ((_tokenSet_5.member(LA(1))) && (_tokenSet_6.member(LA(2)))) {
-				{
-				switch ( LA(1)) {
-				case '\t':  case '\n':  case '\r':  case ' ':
-				{
-					mWS(false);
-					break;
-				}
-				case '(':
-				{
-					break;
-				}
-				default:
-				{
-					throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());
-				}
-				}
-				}
-				match('(');
-				mTEXT_ARG(true);
-				a5=_returnToken;
-				match(')');
-			}
-			else {
-			}
-			
-			}
-			
-						String rule = currentRule.getRuleName();
-						if ( a5!=null ) {
-							rule = a5.getText();
-						}
-						String setName = generator.getFOLLOWBitSet(rule, 1);
-						// System.out.println("FOLLOW("+rule+")="+setName);
-						if ( setName==null ) {
-							reportError("$FOLLOW("+rule+")"+
-										": unknown rule or bad lookahead computation");
-						}
-						else {
-							text.setLength(_begin); text.append(setName);
-						}
-					
-		}
-		else if ((LA(1)=='$') && (LA(2)=='F')) {
-			match("$FIRST");
-			{
-			if ((_tokenSet_5.member(LA(1))) && (_tokenSet_6.member(LA(2)))) {
-				{
-				switch ( LA(1)) {
-				case '\t':  case '\n':  case '\r':  case ' ':
-				{
-					mWS(false);
-					break;
-				}
-				case '(':
-				{
-					break;
-				}
-				default:
-				{
-					throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());
-				}
-				}
-				}
-				match('(');
-				mTEXT_ARG(true);
-				a6=_returnToken;
-				match(')');
-			}
-			else {
-			}
-			
-			}
-			
-						String rule = currentRule.getRuleName();
-						if ( a5!=null ) {
-							rule = a5.getText();
-						}
-						String setName = generator.getFIRSTBitSet(rule, 1);
-						// System.out.println("FIRST("+rule+")="+setName);
-						if ( setName==null ) {
-							reportError("$FIRST("+rule+")"+
-										": unknown rule or bad lookahead computation");
-						}
-						else {
-							text.setLength(_begin); text.append(setName);
-						}
-					
 		}
 		else {
 			throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());
@@ -673,7 +673,7 @@ tryAgain:
 		
 		match('"');
 		{
-		_loop333:
+		_loop599:
 		do {
 			if ((LA(1)=='\\')) {
 				mESC(false);
@@ -682,7 +682,7 @@ tryAgain:
 				matchNot('"');
 			}
 			else {
-				break _loop333;
+				break _loop599;
 			}
 			
 		} while (true);
@@ -798,7 +798,7 @@ tryAgain:
 		}
 		}
 		{
-		_loop262:
+		_loop528:
 		do {
 			if ((LA(1)==',')) {
 				_saveIndex=text.length();
@@ -867,7 +867,7 @@ tryAgain:
 				}
 			}
 			else {
-				break _loop262;
+				break _loop528;
 			}
 			
 		} while (true);
@@ -889,33 +889,33 @@ tryAgain:
 		int _saveIndex;
 		
 		{
-		int _cnt353=0;
-		_loop353:
+		int _cnt619=0;
+		_loop619:
 		do {
-			if ((LA(1)=='\r') && (LA(2)=='\n')) {
+			if ((LA(1)=='\r') && (LA(2)=='\n') && (true)) {
 				match('\r');
 				match('\n');
 				newline();
 			}
-			else if ((LA(1)==' ') && (true)) {
+			else if ((LA(1)==' ') && (true) && (true)) {
 				match(' ');
 			}
-			else if ((LA(1)=='\t') && (true)) {
+			else if ((LA(1)=='\t') && (true) && (true)) {
 				match('\t');
 			}
-			else if ((LA(1)=='\r') && (true)) {
+			else if ((LA(1)=='\r') && (true) && (true)) {
 				match('\r');
 				newline();
 			}
-			else if ((LA(1)=='\n') && (true)) {
+			else if ((LA(1)=='\n') && (true) && (true)) {
 				match('\n');
 				newline();
 			}
 			else {
-				if ( _cnt353>=1 ) { break _loop353; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
+				if ( _cnt619>=1 ) { break _loop619; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
 			}
 			
-			_cnt353++;
+			_cnt619++;
 		} while (true);
 		}
 		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
@@ -971,9 +971,9 @@ tryAgain:
 		}
 		}
 		{
-		_loop319:
+		_loop585:
 		do {
-			if ((_tokenSet_9.member(LA(1))) && (true)) {
+			if ((_tokenSet_9.member(LA(1))) && (true) && (true)) {
 				{
 				switch ( LA(1)) {
 				case 'a':  case 'b':  case 'c':  case 'd':
@@ -1023,7 +1023,7 @@ tryAgain:
 				}
 			}
 			else {
-				break _loop319;
+				break _loop585;
 			}
 			
 		} while (true);
@@ -1261,16 +1261,16 @@ tryAgain:
 		}
 		}
 		{
-		int _cnt293=0;
-		_loop293:
+		int _cnt559=0;
+		_loop559:
 		do {
-			if ((_tokenSet_10.member(LA(1))) && ((LA(2) >= '\u0003' && LA(2) <= '\u00ff'))) {
+			if ((_tokenSet_10.member(LA(1))) && ((LA(2) >= '\u0003' && LA(2) <= '\u00ff')) && (true)) {
 				mTEXT_ARG_ELEMENT(false);
 				{
-				if ((_tokenSet_4.member(LA(1))) && (_tokenSet_11.member(LA(2)))) {
+				if ((_tokenSet_4.member(LA(1))) && (_tokenSet_11.member(LA(2))) && (true)) {
 					mWS(false);
 				}
-				else if ((_tokenSet_11.member(LA(1))) && (true)) {
+				else if ((_tokenSet_11.member(LA(1))) && (true) && (true)) {
 				}
 				else {
 					throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());
@@ -1279,10 +1279,10 @@ tryAgain:
 				}
 			}
 			else {
-				if ( _cnt293>=1 ) { break _loop293; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
+				if ( _cnt559>=1 ) { break _loop559; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
 			}
 			
-			_cnt293++;
+			_cnt559++;
 		} while (true);
 		}
 		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
@@ -1402,12 +1402,12 @@ tryAgain:
 		mID(true);
 		id=_returnToken;
 		{
-		if ((_tokenSet_4.member(LA(1))) && (_tokenSet_13.member(LA(2)))) {
+		if ((_tokenSet_4.member(LA(1))) && (_tokenSet_13.member(LA(2))) && (true)) {
 			_saveIndex=text.length();
 			mWS(false);
 			text.setLength(_saveIndex);
 		}
-		else if ((_tokenSet_13.member(LA(1))) && (true)) {
+		else if ((_tokenSet_13.member(LA(1))) && (true) && (true)) {
 		}
 		else {
 			throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());
@@ -1424,13 +1424,13 @@ tryAgain:
 			{
 				match('<');
 				{
-				_loop276:
+				_loop542:
 				do {
 					if ((_tokenSet_14.member(LA(1)))) {
 						matchNot('>');
 					}
 					else {
-						break _loop276;
+						break _loop542;
 					}
 					
 				} while (true);
@@ -1450,12 +1450,12 @@ tryAgain:
 			}
 			match('(');
 			{
-			if ((_tokenSet_4.member(LA(1))) && (_tokenSet_15.member(LA(2)))) {
+			if ((_tokenSet_4.member(LA(1))) && (_tokenSet_15.member(LA(2))) && ((LA(3) >= '\u0003' && LA(3) <= '\u00ff'))) {
 				_saveIndex=text.length();
 				mWS(false);
 				text.setLength(_saveIndex);
 			}
-			else if ((_tokenSet_15.member(LA(1))) && ((LA(2) >= '\u0003' && LA(2) <= '\u00ff'))) {
+			else if ((_tokenSet_15.member(LA(1))) && ((LA(2) >= '\u0003' && LA(2) <= '\u00ff')) && (true)) {
 			}
 			else {
 				throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());
@@ -1485,7 +1485,7 @@ tryAgain:
 			{
 				mARG(false);
 				{
-				_loop281:
+				_loop547:
 				do {
 					if ((LA(1)==',')) {
 						match(',');
@@ -1528,7 +1528,7 @@ tryAgain:
 						mARG(false);
 					}
 					else {
-						break _loop281;
+						break _loop547;
 					}
 					
 				} while (true);
@@ -1571,8 +1571,8 @@ tryAgain:
 		case '[':
 		{
 			{
-			int _cnt286=0;
-			_loop286:
+			int _cnt552=0;
+			_loop552:
 			do {
 				if ((LA(1)=='[')) {
 					match('[');
@@ -1635,10 +1635,10 @@ tryAgain:
 					match(']');
 				}
 				else {
-					if ( _cnt286>=1 ) { break _loop286; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
+					if ( _cnt552>=1 ) { break _loop552; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
 				}
 				
-				_cnt286++;
+				_cnt552++;
 			} while (true);
 			}
 			break;
@@ -1656,11 +1656,11 @@ tryAgain:
 			break;
 		}
 		default:
-			if ((LA(1)=='-') && (LA(2)=='>')) {
+			if ((LA(1)=='-') && (LA(2)=='>') && (_tokenSet_12.member(LA(3)))) {
 				match("->");
 				mID_ELEMENT(false);
 			}
-			else if ((_tokenSet_16.member(LA(1))) && (true)) {
+			else if ((_tokenSet_16.member(LA(1))) && (true) && (true)) {
 				
 								mapped = true;
 								String t = generator.mapTreeId(id.getText(), transInfo);
@@ -1670,7 +1670,7 @@ tryAgain:
 								}
 							
 				{
-				if (((_tokenSet_17.member(LA(1))) && (_tokenSet_16.member(LA(2))))&&(transInfo!=null && transInfo.refRuleRoot!=null)) {
+				if (((_tokenSet_17.member(LA(1))) && (_tokenSet_16.member(LA(2))) && (true))&&(transInfo!=null && transInfo.refRuleRoot!=null)) {
 					{
 					switch ( LA(1)) {
 					case '\t':  case '\n':  case '\r':  case ' ':
@@ -1690,7 +1690,7 @@ tryAgain:
 					}
 					mVAR_ASSIGN(false);
 				}
-				else if ((_tokenSet_18.member(LA(1))) && (true)) {
+				else if ((_tokenSet_18.member(LA(1))) && (true) && (true)) {
 				}
 				else {
 					throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());
@@ -1719,10 +1719,10 @@ tryAgain:
 		_ttype = AST_CTOR_ELEMENT;
 		int _saveIndex;
 		
-		if ((LA(1)=='"') && ((LA(2) >= '\u0003' && LA(2) <= '\u00ff'))) {
+		if ((LA(1)=='"') && ((LA(2) >= '\u0003' && LA(2) <= '\u00ff')) && ((LA(3) >= '\u0003' && LA(3) <= '\u00ff'))) {
 			mSTRING(false);
 		}
-		else if ((_tokenSet_19.member(LA(1))) && ((LA(2) >= '\u0003' && LA(2) <= '\u00ff'))) {
+		else if ((_tokenSet_19.member(LA(1))) && ((LA(2) >= '\u0003' && LA(2) <= '\u00ff')) && (true)) {
 			mTREE_ELEMENT(false);
 		}
 		else if (((LA(1) >= '0' && LA(1) <= '9'))) {
@@ -1745,17 +1745,17 @@ tryAgain:
 		int _saveIndex;
 		
 		{
-		int _cnt344=0;
-		_loop344:
+		int _cnt610=0;
+		_loop610:
 		do {
 			if (((LA(1) >= '0' && LA(1) <= '9'))) {
 				mDIGIT(false);
 			}
 			else {
-				if ( _cnt344>=1 ) { break _loop344; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
+				if ( _cnt610>=1 ) { break _loop610; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
 			}
 			
-			_cnt344++;
+			_cnt610++;
 		} while (true);
 		}
 		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
@@ -1785,10 +1785,10 @@ tryAgain:
 			break;
 		}
 		default:
-			if ((_tokenSet_19.member(LA(1))) && ((LA(2) >= '\u0003' && LA(2) <= '\u00ff'))) {
+			if ((_tokenSet_19.member(LA(1))) && ((LA(2) >= '\u0003' && LA(2) <= '\u00ff')) && ((LA(3) >= '\u0003' && LA(3) <= '\u00ff'))) {
 				mTREE_ELEMENT(false);
 			}
-			else if ((LA(1)=='"') && ((LA(2) >= '\u0003' && LA(2) <= '\u00ff'))) {
+			else if ((LA(1)=='"') && ((LA(2) >= '\u0003' && LA(2) <= '\u00ff')) && ((LA(3) >= '\u0003' && LA(3) <= '\u00ff'))) {
 				mSTRING(false);
 			}
 		else {
@@ -1797,9 +1797,9 @@ tryAgain:
 		}
 		}
 		{
-		_loop314:
+		_loop580:
 		do {
-			if ((_tokenSet_20.member(LA(1))) && (_tokenSet_21.member(LA(2)))) {
+			if ((_tokenSet_20.member(LA(1))) && (_tokenSet_21.member(LA(2))) && ((LA(3) >= '\u0003' && LA(3) <= '\u00ff'))) {
 				{
 				switch ( LA(1)) {
 				case '\t':  case '\n':  case '\r':  case ' ':
@@ -1882,7 +1882,7 @@ tryAgain:
 				mARG(false);
 			}
 			else {
-				break _loop314;
+				break _loop580;
 			}
 			
 		} while (true);
@@ -1966,12 +1966,12 @@ tryAgain:
 		mID(true);
 		id=_returnToken;
 		{
-		if ((_tokenSet_4.member(LA(1))) && (_tokenSet_22.member(LA(2)))) {
+		if ((_tokenSet_4.member(LA(1))) && (_tokenSet_22.member(LA(2))) && (true)) {
 			_saveIndex=text.length();
 			mWS(false);
 			text.setLength(_saveIndex);
 		}
-		else if ((_tokenSet_22.member(LA(1))) && (true)) {
+		else if ((_tokenSet_22.member(LA(1))) && (true) && (true)) {
 		}
 		else {
 			throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());
@@ -1984,12 +1984,12 @@ tryAgain:
 		{
 			match('(');
 			{
-			if ((_tokenSet_4.member(LA(1))) && (_tokenSet_23.member(LA(2)))) {
+			if ((_tokenSet_4.member(LA(1))) && (_tokenSet_23.member(LA(2))) && ((LA(3) >= '\u0003' && LA(3) <= '\u00ff'))) {
 				_saveIndex=text.length();
 				mWS(false);
 				text.setLength(_saveIndex);
 			}
-			else if ((_tokenSet_23.member(LA(1))) && ((LA(2) >= '\u0003' && LA(2) <= '\u00ff'))) {
+			else if ((_tokenSet_23.member(LA(1))) && ((LA(2) >= '\u0003' && LA(2) <= '\u00ff')) && (true)) {
 			}
 			else {
 				throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());
@@ -1997,26 +1997,26 @@ tryAgain:
 			
 			}
 			{
-			_loop302:
+			_loop568:
 			do {
-				if ((_tokenSet_24.member(LA(1))) && ((LA(2) >= '\u0003' && LA(2) <= '\u00ff'))) {
+				if ((_tokenSet_24.member(LA(1))) && ((LA(2) >= '\u0003' && LA(2) <= '\u00ff')) && ((LA(3) >= '\u0003' && LA(3) <= '\u00ff'))) {
 					mTEXT_ARG(false);
 					{
-					_loop301:
+					_loop567:
 					do {
 						if ((LA(1)==',')) {
 							match(',');
 							mTEXT_ARG(false);
 						}
 						else {
-							break _loop301;
+							break _loop567;
 						}
 						
 					} while (true);
 					}
 				}
 				else {
-					break _loop302;
+					break _loop568;
 				}
 				
 			} while (true);
@@ -2046,18 +2046,18 @@ tryAgain:
 		case '[':
 		{
 			{
-			int _cnt307=0;
-			_loop307:
+			int _cnt573=0;
+			_loop573:
 			do {
 				if ((LA(1)=='[')) {
 					match('[');
 					{
-					if ((_tokenSet_4.member(LA(1))) && (_tokenSet_24.member(LA(2)))) {
+					if ((_tokenSet_4.member(LA(1))) && (_tokenSet_24.member(LA(2))) && ((LA(3) >= '\u0003' && LA(3) <= '\u00ff'))) {
 						_saveIndex=text.length();
 						mWS(false);
 						text.setLength(_saveIndex);
 					}
-					else if ((_tokenSet_24.member(LA(1))) && ((LA(2) >= '\u0003' && LA(2) <= '\u00ff'))) {
+					else if ((_tokenSet_24.member(LA(1))) && ((LA(2) >= '\u0003' && LA(2) <= '\u00ff')) && ((LA(3) >= '\u0003' && LA(3) <= '\u00ff'))) {
 					}
 					else {
 						throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());
@@ -2087,10 +2087,10 @@ tryAgain:
 					match(']');
 				}
 				else {
-					if ( _cnt307>=1 ) { break _loop307; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
+					if ( _cnt573>=1 ) { break _loop573; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
 				}
 				
-				_cnt307++;
+				_cnt573++;
 			} while (true);
 			}
 			break;
@@ -2108,11 +2108,11 @@ tryAgain:
 			break;
 		}
 		default:
-			if ((LA(1)==':') && (LA(2)==':')) {
+			if ((LA(1)==':') && (LA(2)==':') && (_tokenSet_12.member(LA(3)))) {
 				match("::");
 				mTEXT_ARG_ID_ELEMENT(false);
 			}
-			else if ((_tokenSet_11.member(LA(1))) && (true)) {
+			else if ((_tokenSet_11.member(LA(1))) && (true) && (true)) {
 			}
 		else {
 			throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());
@@ -2132,42 +2132,42 @@ tryAgain:
 		int _saveIndex;
 		
 		{
-		int _cnt347=0;
-		_loop347:
+		int _cnt613=0;
+		_loop613:
 		do {
-			if (((LA(1) >= '0' && LA(1) <= '9')) && (_tokenSet_25.member(LA(2)))) {
+			if (((LA(1) >= '0' && LA(1) <= '9')) && (_tokenSet_25.member(LA(2))) && (true)) {
 				mDIGIT(false);
 			}
 			else {
-				if ( _cnt347>=1 ) { break _loop347; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
+				if ( _cnt613>=1 ) { break _loop613; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
 			}
 			
-			_cnt347++;
+			_cnt613++;
 		} while (true);
 		}
 		{
-		if ((LA(1)=='L') && (_tokenSet_26.member(LA(2)))) {
+		if ((LA(1)=='L') && (_tokenSet_26.member(LA(2))) && (true)) {
 			match('L');
 		}
-		else if ((LA(1)=='l') && (_tokenSet_26.member(LA(2)))) {
+		else if ((LA(1)=='l') && (_tokenSet_26.member(LA(2))) && (true)) {
 			match('l');
 		}
 		else if ((LA(1)=='.')) {
 			match('.');
 			{
-			_loop350:
+			_loop616:
 			do {
-				if (((LA(1) >= '0' && LA(1) <= '9')) && (_tokenSet_26.member(LA(2)))) {
+				if (((LA(1) >= '0' && LA(1) <= '9')) && (_tokenSet_26.member(LA(2))) && (true)) {
 					mDIGIT(false);
 				}
 				else {
-					break _loop350;
+					break _loop616;
 				}
 				
 			} while (true);
 			}
 		}
-		else if ((_tokenSet_26.member(LA(1))) && (true)) {
+		else if ((_tokenSet_26.member(LA(1))) && (true) && (true)) {
 		}
 		else {
 			throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());
@@ -2188,27 +2188,27 @@ tryAgain:
 		
 		match("//");
 		{
-		_loop324:
+		_loop590:
 		do {
 			// nongreedy exit test
-			if ((LA(1)=='\n'||LA(1)=='\r') && (true)) break _loop324;
-			if (((LA(1) >= '\u0003' && LA(1) <= '\u00ff')) && ((LA(2) >= '\u0003' && LA(2) <= '\u00ff'))) {
+			if ((LA(1)=='\n'||LA(1)=='\r') && (true) && (true)) break _loop590;
+			if (((LA(1) >= '\u0003' && LA(1) <= '\u00ff')) && ((LA(2) >= '\u0003' && LA(2) <= '\u00ff')) && (true)) {
 				matchNot(EOF_CHAR);
 			}
 			else {
-				break _loop324;
+				break _loop590;
 			}
 			
 		} while (true);
 		}
 		{
-		if ((LA(1)=='\r') && (LA(2)=='\n')) {
+		if ((LA(1)=='\r') && (LA(2)=='\n') && (true)) {
 			match("\r\n");
 		}
 		else if ((LA(1)=='\n')) {
 			match('\n');
 		}
-		else if ((LA(1)=='\r') && (true)) {
+		else if ((LA(1)=='\r') && (true) && (true)) {
 			match('\r');
 		}
 		else {
@@ -2231,28 +2231,28 @@ tryAgain:
 		
 		match("/*");
 		{
-		_loop328:
+		_loop594:
 		do {
 			// nongreedy exit test
-			if ((LA(1)=='*') && (LA(2)=='/')) break _loop328;
-			if ((LA(1)=='\r') && (LA(2)=='\n')) {
+			if ((LA(1)=='*') && (LA(2)=='/') && (true)) break _loop594;
+			if ((LA(1)=='\r') && (LA(2)=='\n') && ((LA(3) >= '\u0003' && LA(3) <= '\u00ff'))) {
 				match('\r');
 				match('\n');
 				newline();
 			}
-			else if ((LA(1)=='\r') && ((LA(2) >= '\u0003' && LA(2) <= '\u00ff'))) {
+			else if ((LA(1)=='\r') && ((LA(2) >= '\u0003' && LA(2) <= '\u00ff')) && ((LA(3) >= '\u0003' && LA(3) <= '\u00ff'))) {
 				match('\r');
 				newline();
 			}
-			else if ((LA(1)=='\n') && ((LA(2) >= '\u0003' && LA(2) <= '\u00ff'))) {
+			else if ((LA(1)=='\n') && ((LA(2) >= '\u0003' && LA(2) <= '\u00ff')) && ((LA(3) >= '\u0003' && LA(3) <= '\u00ff'))) {
 				match('\n');
 				newline();
 			}
-			else if (((LA(1) >= '\u0003' && LA(1) <= '\u00ff')) && ((LA(2) >= '\u0003' && LA(2) <= '\u00ff'))) {
+			else if (((LA(1) >= '\u0003' && LA(1) <= '\u00ff')) && ((LA(2) >= '\u0003' && LA(2) <= '\u00ff')) && ((LA(3) >= '\u0003' && LA(3) <= '\u00ff'))) {
 				matchNot(EOF_CHAR);
 			}
 			else {
-				break _loop328;
+				break _loop594;
 			}
 			
 		} while (true);
@@ -2288,6 +2288,11 @@ tryAgain:
 			match('t');
 			break;
 		}
+		case 'v':
+		{
+			match('v');
+			break;
+		}
 		case 'b':
 		{
 			match('b');
@@ -2319,13 +2324,13 @@ tryAgain:
 			matchRange('0','3');
 			}
 			{
-			if (((LA(1) >= '0' && LA(1) <= '9')) && ((LA(2) >= '\u0003' && LA(2) <= '\u00ff'))) {
+			if (((LA(1) >= '0' && LA(1) <= '9')) && ((LA(2) >= '\u0003' && LA(2) <= '\u00ff')) && (true)) {
 				mDIGIT(false);
 				{
-				if (((LA(1) >= '0' && LA(1) <= '9')) && ((LA(2) >= '\u0003' && LA(2) <= '\u00ff'))) {
+				if (((LA(1) >= '0' && LA(1) <= '9')) && ((LA(2) >= '\u0003' && LA(2) <= '\u00ff')) && (true)) {
 					mDIGIT(false);
 				}
-				else if (((LA(1) >= '\u0003' && LA(1) <= '\u00ff')) && (true)) {
+				else if (((LA(1) >= '\u0003' && LA(1) <= '\u00ff')) && (true) && (true)) {
 				}
 				else {
 					throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());
@@ -2333,7 +2338,7 @@ tryAgain:
 				
 				}
 			}
-			else if (((LA(1) >= '\u0003' && LA(1) <= '\u00ff')) && (true)) {
+			else if (((LA(1) >= '\u0003' && LA(1) <= '\u00ff')) && (true) && (true)) {
 			}
 			else {
 				throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());
@@ -2348,10 +2353,10 @@ tryAgain:
 			matchRange('4','7');
 			}
 			{
-			if (((LA(1) >= '0' && LA(1) <= '9')) && ((LA(2) >= '\u0003' && LA(2) <= '\u00ff'))) {
+			if (((LA(1) >= '0' && LA(1) <= '9')) && ((LA(2) >= '\u0003' && LA(2) <= '\u00ff')) && (true)) {
 				mDIGIT(false);
 			}
-			else if (((LA(1) >= '\u0003' && LA(1) <= '\u00ff')) && (true)) {
+			else if (((LA(1) >= '\u0003' && LA(1) <= '\u00ff')) && (true) && (true)) {
 			}
 			else {
 				throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());
