@@ -62,8 +62,15 @@ int main( int argc, char*argv[] )
 		else
 			cout << "No tree produced" << endl;
 	}
+	catch(ANTLRException& e)
+	{
+		cerr << "Parse exception: " << e.toString() << endl;
+		return -1;
+	}
 	catch(exception& e)
 	{
 		cerr << "exception: " << e.what() << endl;
+		return -1;
 	}
+	return 0;
 }
