@@ -1,4 +1,6 @@
+
 #include <iostream>
+
 #include "CalcLexer.hpp"
 #include "CalcParser.hpp"
 #include "CalcAST.hpp"
@@ -33,8 +35,15 @@ int main()
 		else
 			cerr << "Errors encountered during parse.." << endl;
 	}
+	catch( ANTLRException& e )
+	{
+		cerr << "ANTLRException: " << e.getMessage() << endl;
+		return -1;
+	}
 	catch(exception& e)
 	{
 		cerr << "exception: " << e.what() << endl;
+		return -1;
 	}
+	return 0;
 }
