@@ -50,6 +50,10 @@ public:
 	}
 };
 
+#if (_MSC_VER == 1300 )
+extern template class ANTLR_USE_NAMESPACE(antlr)ASTRefCount<PLUSNode>;
+#endif
+
 typedef ANTLR_USE_NAMESPACE(antlr)ASTRefCount<PLUSNode> RefPLUSNode;
 
 #endif //INC_PLUSNode_hpp__
