@@ -1,8 +1,10 @@
+
+#include <iostream>
+
 #include "DemoJavaLexer.hpp"
 #include "DemoJavaDocLexer.hpp"
 #include "DemoJavaParser.hpp"
 #include "antlr/TokenStreamSelector.hpp"
-#include <iostream>
 
 int main()
 {
@@ -38,8 +40,16 @@ int main()
 			cout << t->toString() << endl;
 		}
 	}
-	catch(exception& e) {
-		cerr << "exception: " << e.what() << endl;
+	catch( ANTLRException& e )
+	{
+		cerr << "exception: " << e.getMessage() << endl;
+		return -1;
 	}
+	catch( exception& e )
+	{
+		cerr << "exception: " << e.what() << endl;
+		return -1;
+	}
+	return 0;
 }
 
