@@ -1,4 +1,6 @@
+
 #include <iostream>
+
 #include "SimpleLexer.hpp"
 #include "SimpleParser.hpp"
 #include "SimpleParser2.hpp"
@@ -29,9 +31,16 @@ int main()
 		SimpleParser2 parser2(inputstate);
 		parser2.simple();
 	}
-	catch(exception& e)
+	catch( ANTLRException& e )
+	{
+		cerr << "exception: " << e.getMessage() << endl;
+		return -1;
+	}
+	catch( exception& e )
 	{
 		cerr << "exception: " << e.what() << endl;
+		return -1;
 	}
+	return 0;
 }
 
