@@ -1,6 +1,12 @@
 using System;
-using CharBuffer   = antlr.CharBuffer;
-using Token			 = antlr.Token;
+using CharBuffer 	= antlr.CharBuffer;
+using Token 		= antlr.Token;
+using IToken 		= antlr.IToken;
+
+// wh: bug(?) in DotGNU 0.6 - "using antlr" will workaround the problem.
+#if __CSCC__
+using antlr;
+#endif
 	
 class Test 
 {
@@ -12,7 +18,7 @@ class Test
 			bool done = false;
 			while ( !done ) 
 			{
-				Token tok = lexer.nextToken();
+				IToken tok = lexer.nextToken();
 				Console.Out.WriteLine("Token: "+tok);
 				if ( tok.Type==Token.EOF_TYPE ) {
 					done = true;
