@@ -5,25 +5,24 @@
  * Project led by Terence Parr at http://www.jGuru.com
  * Software rights: http://www.antlr.org/license.html
  *
- * $Id: //depot/code/org.antlr/release/antlr-2.7.4/lib/cpp/antlr/Token.hpp#1 $
+ * $Id: //depot/code/org.antlr/release/antlr-2.7.7/lib/cpp/antlr/Token.hpp#2 $
  */
 
 #include <antlr/config.hpp>
-#include <antlr/RefCount.hpp>
+#include <antlr/TokenRefCount.hpp>
 #include <string>
 
 #ifdef ANTLR_CXX_SUPPORTS_NAMESPACE
 namespace antlr {
 #endif
 
+struct TokenRef;
+
 /** A token is minimally a token type.  Subclasses can add the text matched
  *  for the token and line info.
  */
-
-class ANTLR_API Token;
-typedef RefCount<Token> RefToken;
-
-class ANTLR_API Token {
+class ANTLR_API Token
+{
 public:
 	// constants
 #ifndef NO_STATIC_CONSTS
@@ -42,20 +41,30 @@ public:
 	};
 #endif
 
-	// each Token has at least a token type
-	int type; //=INVALID_TYPE;
-
-public:
-	// the illegal token object
-	static RefToken badToken; // = new Token(INVALID_TYPE, "<no text>");
-
-	Token();
-	Token(int t);
-	Token(int t, const ANTLR_USE_NAMESPACE(std)string& txt);
+	Token()
+	: ref(0)
+	, type(INVALID_TYPE)
+	{
+	}
+	Token(int t)
+	: ref(0)
+	, type(t)
+	{
+	}
+	Token(int t, const ANTLR_USE_NAMESPACE(std)string& txt)
+	: ref(0)
+	, type(t)
+	{
+		setText(txt);
+	}
+	virtual ~Token()
+	{
+	}
 
 	virtual int getColumn() const;
 	virtual int getLine() const;
 	virtual ANTLR_USE_NAMESPACE(std)string getText() const;
+	virtual const ANTLR_USE_NAMESPACE(std)string& getFilename() const;
 	virtual int getType() const;
 
 	virtual void setColumn(int c);
@@ -64,12 +73,21 @@ public:
 	virtual void setText(const ANTLR_USE_NAMESPACE(std)string& t);
 	virtual void setType(int t);
 
+	virtual void setFilename( const std::string& file );
+
 	virtual ANTLR_USE_NAMESPACE(std)string toString() const;
 
-	virtual ~Token();
 private:
+	friend struct TokenRef;
+	TokenRef* ref;
+
+	int type; 							///< the type of the token
+
+	Token(RefToken other);
+	Token& operator=(const Token& other);
+	Token& operator=(RefToken other);
+
 	Token(const Token&);
-	const Token& operator=(const Token&);
 };
 
 extern ANTLR_API RefToken nullToken;
