@@ -16,7 +16,7 @@ using System.Runtime.CompilerServices;
 [assembly: AssemblyTrademark("")]
 [assembly: AssemblyCulture("")]
 
-[assembly: AssemblyVersion("2.7.6.02")]
+[assembly: AssemblyVersion("2.7.7.01")]
 
 
 // Version information for an assembly consists of the following four values:
@@ -30,3 +30,15 @@ using System.Runtime.CompilerServices;
 // by using the '*' as shown below:
 
 [assembly: CLSCompliantAttribute(true)]
+
+#if STRONGNAME
+#pragma warning disable 1699
+[assembly: AssemblyDelaySign(false)]
+[assembly: AssemblyKeyFile("org.antlr.snk")]
+#pragma warning restore 1699
+#endif
+
+
+#if APTC
+[assembly: System.Security.AllowPartiallyTrustedCallers]
+#endif
\ No newline at end of file
