@@ -2553,7 +2553,7 @@ class CommonASTWithHiddenTokens(CommonAST):
         CommonAST.initialize(self,*args)
         if args and isinstance(args[0],Token):
             assert isinstance(args[0],CommonHiddenStreamToken)
-            self.hideenBefore = args[0].getHiddenBefore()
+            self.hiddenBefore = args[0].getHiddenBefore()
             self.hiddenAfter  = args[0].getHiddenAfter()
 
 ###xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx###
